@@ -232,25 +232,29 @@ def log(value=None, showpath=False):
 	if showpath:
 		return __abs(filename)
 	else:
+		time = __dtime.now().strftime("%H:%M:%S")
+
 		if __exs(filename):
 			file = open(filename, "a")
-			time = __dtime.now().strftime("%H:%M:%S")
 			data = f"\n\nNew Match played at {time}\n"
-			file.write(data + "-"*9 + "\n")
+
+			file.write(data + "-"*len(data) + f"\n{value}")
+			file.close()
 		else:
 			file = open(filename, "w")
+			data = f"New Match played at {time}\n"
 
-		file.write(f"{value}")
-		file.close()
+			file.write(data + "-"*len(data) + f"\n{value}")
+			file.close()
 
 # Displaying the Probability
 def showProb():
 	""" Displays the Probability recorded so far"""
 
 	try:
-		file1 = open("prob.json")
+		file1 = open(f"{__abs('.')}/prob.json")
 	except FileNotFoundError:
-		with open("prob.json", "w") as file:
+		with open(f"{__abs('.')}/prob.json", "w") as file:
 			newData = {"Total Games Played": 0,
 						"Total Computer Wins": 0,
 						"Total Player Wins": 0,
@@ -260,7 +264,7 @@ def showProb():
 						"Game Drawing Probability": 0}
 			file.write(__dumps(newData, indent=4))
 
-		file1 = open("prob.json")
+		file1 = open(f"{__abs('.')}/prob.json")
 
 	data = __load(file1)
 
